summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /kmail/kmheaders.cpp
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kmail/kmheaders.cpp')
-rw-r--r--kmail/kmheaders.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/kmail/kmheaders.cpp b/kmail/kmheaders.cpp
index 6910ad6e..740dde83 100644
--- a/kmail/kmheaders.cpp
+++ b/kmail/kmheaders.cpp
@@ -94,7 +94,7 @@ TQPixmap* KMHeaders::pixReadFwdReplied = 0;
//-----------------------------------------------------------------------------
KMHeaders::KMHeaders(KMMainWidget *aOwner, TQWidget *parent,
const char *name) :
- KListView( parent, name ),
+ TDEListView( parent, name ),
mIgnoreSortOrderChanges( false )
{
static bool pixmapsLoaded = false;
@@ -126,7 +126,7 @@ KMHeaders::KMHeaders(KMMainWidget *aOwner, TQWidget *parent,
// popup-menu
header()->setClickEnabled(true);
header()->installEventFilter(this);
- mPopup = new KPopupMenu(this);
+ mPopup = new TDEPopupMenu(this);
mPopup->insertTitle(i18n("View Columns"));
mPopup->setCheckable(true);
mPopup->insertItem(i18n("Status"), KPaintInfo::COL_STATUS);
@@ -252,7 +252,7 @@ bool KMHeaders::eventFilter ( TQObject *o, TQEvent *e )
mPopup->popup( TQT_TQMOUSEEVENT(e)->globalPos() );
return true;
}
- return KListView::eventFilter(o, e);
+ return TDEListView::eventFilter(o, e);
}
//-----------------------------------------------------------------------------
@@ -414,7 +414,7 @@ void KMHeaders::paintEmptyArea( TQPainter * p, const TQRect & rect )
bool KMHeaders::event(TQEvent *e)
{
- bool result = KListView::event(e);
+ bool result = TDEListView::event(e);
if (e->type() == TQEvent::ApplicationPaletteChange)
{
readColorConfig();
@@ -559,7 +559,7 @@ void KMHeaders::readConfig (void)
//-----------------------------------------------------------------------------
void KMHeaders::restoreColumnLayout( TDEConfig *config, const TQString &group )
{
// KListView::restoreLayout() will call setSorting(), which is reimplemented by us.
// We don't want to change the sort order, so we set a flag here that is checked in
// setSorting().
mIgnoreSortOrderChanges = true;
@@ -1054,7 +1054,7 @@ void KMHeaders::msgAdded(int id)
}
if (mSortInfo.fakeSort) {
TQObject::disconnect(header(), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(dirtySortOrder(int)));
- KListView::setSorting(mSortCol, !mSortDescending );
+ TDEListView::setSorting(mSortCol, !mSortDescending );
mSortInfo.fakeSort = 0;
}
appendItemToSortFile(hi); //inserted into sorted list
@@ -1139,7 +1139,7 @@ void KMHeaders::msgRemoved(int id, TQString msgId )
item->setTempKey( key + item->key( mSortCol, !mSortDescending ));
if (mSortInfo.fakeSort) {
TQObject::disconnect(header(), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(dirtySortOrder(int)));
- KListView::setSorting(mSortCol, !mSortDescending );
+ TDEListView::setSorting(mSortCol, !mSortDescending );
mSortInfo.fakeSort = 0;
}
}
@@ -1385,7 +1385,7 @@ void KMHeaders::setStyleDependantFrameWidth()
void KMHeaders::styleChange( TQStyle& oldStyle )
{
setStyleDependantFrameWidth();
- KListView::styleChange( oldStyle );
+ TDEListView::styleChange( oldStyle );
}
//-----------------------------------------------------------------------------
@@ -1711,7 +1711,7 @@ void KMHeaders::setSelected( TQListViewItem *item, bool selected )
return;
if ( item->isVisible() )
- KListView::setSelected( item, selected );
+ TDEListView::setSelected( item, selected );
// If the item is the parent of a closed thread recursively select
// children .
@@ -2190,7 +2190,7 @@ void KMHeaders::updateMessageList( bool set_selection, bool forceJumpToUnread )
clear();
mItems.resize(0); // will contain deleted pointers
noRepaint = false;
- KListView::setSorting( mSortCol, !mSortDescending );
+ TDEListView::setSorting( mSortCol, !mSortDescending );
if (!mFolder) {
repaint();
return;
@@ -2251,7 +2251,7 @@ void KMHeaders::keyPressEvent( TQKeyEvent * e )
case Key_Next:
case Key_Prior:
case Key_Escape:
- KListView::keyPressEvent( e );
+ TDEListView::keyPressEvent( e );
}
if (!shft)
connect(this,TQT_SIGNAL(currentChanged(TQListViewItem*)),
@@ -2302,7 +2302,7 @@ void KMHeaders::contentsMousePressEvent(TQMouseEvent* e)
}
// let klistview do it's thing, expanding/collapsing, selection/deselection
- KListView::contentsMousePressEvent(e);
+ TDEListView::contentsMousePressEvent(e);
/* TQListView's shift-select selects also invisible items. Until that is
fixed, we have to deselect hidden items here manually, so the quick
search doesn't mess things up. */
@@ -2367,7 +2367,7 @@ void KMHeaders::contentsMousePressEvent(TQMouseEvent* e)
void KMHeaders::contentsMouseReleaseEvent(TQMouseEvent* e)
{
if (e->button() != Qt::RightButton)
- KListView::contentsMouseReleaseEvent(e);
+ TDEListView::contentsMouseReleaseEvent(e);
mMousePressed = false;
}
@@ -2507,7 +2507,7 @@ void KMHeaders::slotRMB()
menu->insertSeparator();
mOwner->messageActions()->createTodoAction()->plug( menu );
- KAcceleratorManager::manage(menu);
+ TDEAcceleratorManager::manage(menu);
kmkernel->setContextMenuShown( true );
menu->exec(TQCursor::pos(), 0);
kmkernel->setContextMenuShown( false );
@@ -2648,7 +2648,7 @@ void KMHeaders::setSorting( int column, bool ascending )
colText = colText + i18n( " (Status)" );
setColumnText( mPaintInfo.subCol, colText);
}
- KListView::setSorting( column, ascending );
+ TDEListView::setSorting( column, ascending );
ensureCurrentItemVisible();
// Make sure the config and .sorted file are updated, otherwise stale info
// is read on new imap mail. ( folder->folderComplete() -> readSortOrder() ).
@@ -3108,7 +3108,7 @@ bool KMHeaders::readSortOrder( bool set_selection, bool forceJumpToUnread )
fread(&sorted_count, sizeof(sorted_count), 1, sortStream);
//Hackyness to work around qlistview problems
- KListView::setSorting(-1);
+ TDEListView::setSorting(-1);
header()->setSortIndicator(column, ascending);
TQObject::connect(header(), TQT_SIGNAL(clicked(int)), this, TQT_SLOT(dirtySortOrder(int)));
//setup mSortInfo here now, as above may change it
@@ -3228,7 +3228,7 @@ bool KMHeaders::readSortOrder( bool set_selection, bool forceJumpToUnread )
mSortInfo.ascending = ascending = !mSortDescending;
threaded = (isThreaded());
sorted_count = discovered_count = appended = 0;
- KListView::setSorting( mSortCol, !mSortDescending );
+ TDEListView::setSorting( mSortCol, !mSortDescending );
}
//fill in empty holes
if((sorted_count + discovered_count - deleted_count) < mFolder->count()) {
@@ -3566,9 +3566,9 @@ void KMHeaders::pasteMessages()
void KMHeaders::updateActions()
{
- KAction *copy = owner()->action( "copy_messages" );
- KAction *cut = owner()->action( "cut_messages" );
- KAction *paste = owner()->action( "paste_messages" );
+ TDEAction *copy = owner()->action( "copy_messages" );
+ TDEAction *cut = owner()->action( "cut_messages" );
+ TDEAction *paste = owner()->action( "paste_messages" );
if ( selectedItems().isEmpty() ) {
copy->setEnabled( false );
@@ -559,7 +559,7 @@ void KMHeaders::readConfig (void)
void KMHeaders::restoreColumnLayout( TDEConfig *config, const TQString &group )
{
- // KListView::restoreLayout() will call setSorting(), which is reimplemented by us.
+ // TDEListView::restoreLayout() will call setSorting(), which is reimplemented by us.
// We don't want to change the sort order, so we set a flag here that is checked in
// setSorting().